@@ -1,6 +1,6 @@
-" m3u_to_pyradio -- File converter to pyradio. "
+"""m3u_to_pyradio -- File converter to pyradio."""
 
-version_info = (0, 0, 2)
+version_info = (0, 0, 3)
 
 __version__ = version = ".".join(map(str, version_info))
 __project__ = __name__
